@@ -24,7 +24,7 @@ BEGIN {
   }
 }
 
-our $VERSION = "0.11";
+our $VERSION = "1.00";
 
 # Var: $DEFAULT
 #   Use it to redefine default Pony's options.
@@ -288,20 +288,20 @@ sub predefine {
       if (defined wantarray) {
         if (wantarray == 0) {
           my $ret = eval{ $try->() };
-          $ret = $catch->($@) if $@;
+          $ret = $catch->($@) if $@ && defined $catch;
           $ret = $finally->() if defined $finally;
           return $ret;
         }
         elsif (wantarray == 1) {
           my @ret = eval{ $try->() };
-          @ret = $catch->($@) if $@;
+          @ret = $catch->($@) if $@ && defined $catch;
           @ret = $finally->() if defined $finally;
           return @ret;
         }
       }
       else {
         eval{ $try->() };
-        $catch->($@) if $@;
+        $catch->($@) if $@ && defined $catch;
         $finally->() if defined $finally;
       }
     };
@@ -800,7 +800,7 @@ Pony::Object - An object system.
 
 =head1 OVERVIEW
 
-If you wanna protected methods, abstract classes and other stuff like with, you
+If you wanna protected methods, abstract classes and other OOP stuff, you
 may use Pony::Object. Also Pony::Objects are strict and modern.
 
 =head1 SYNOPSIS
@@ -890,7 +890,7 @@ may use Pony::Object. Also Pony::Objects are strict and modern.
 
 =head2 has
 
-Keyword C<has> declares new property. You also can define methods via C<has>.
+Keyword C<has> declares new property. Also you can define methods via C<has>.
 
   package News;
   use Pony::Object;
